@@ -13,6 +13,7 @@ import netjfwatcher.common.view.AbstractTableView;
 import netjfwatcher.common.view.TableListViewColor;
 import netjfwatcher.database.access.model.DBTableAlarm;
 import netjfwatcher.engine.model.action.ActionBuilderAlarmList;
+import netjfwatcher.engine.model.action.EngineStatus;
 import netjfwatcher.engine.model.action.ActionBuilderAlarmList.ActionConfirmAlarm;
 import netjfwatcher.engine.model.action.ActionBuilderAlarmList.ActionConfirmAlarmSocket;
 import netjfwatcher.engine.model.action.ActionBuilderAlarmList.ActionConfirmAllAlarm;
@@ -33,7 +34,6 @@ import org.eclipse.swt.events.ControlEvent;
 import org.eclipse.swt.events.ControlListener;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
-import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -69,7 +69,6 @@ public class EditorAllNodeAlarm extends EditorNodeAlarm {
 	/* A[e[uANZXɑSm[hIPAhX\R[h */
 	private static final String ALARM_ALL = "all";
 
-
 	/* AlarmɊւANV */
 	private AlarmAction alarmAction = new AlarmAction();
 
@@ -647,6 +646,12 @@ public class EditorAllNodeAlarm extends EditorNodeAlarm {
 		}
 	}
 
+	public void setFocus() {
+		if (EngineStatus.getInstance().isEngine()) {
+			setNodeAlarmeView("all", sortColumn, sortDirection);
+		}
+	}
+
 	/**
 	 * Alarme[uɊւANV`ANVNXłB
 	 * 
